# 0xdirsan

[![made-with-Python](https://img.shields.io/badge/made%20with-Python-pink.svg)](https://www.python.org/)
[![license](https://img.shields.io/badge/license-MIT-pink.svg)](LICENSE)
[![issues](https://img.shields.io/github/issues/X-Projetion/0xdirsan?color=pink)](https://github.com/X-Projetion/0xdirsan/issues)

<p align="center">
    <img src="https://raw.githubusercontent.com/X-Projetion/0xdirsan/main/0xdirsan.png" alt="0xdirsan" width="60%">
</p>
<h4 align="center">0xdirsan is a simple program designed to search for directories in the file system</h4>

# 0xdirsan
0xdirsan is a simple program designed to search for directories within the file system using brute-force with a given list of words.

## Resources
- [Feature](#feature)
- [Installation](#installation)
- [Pypi](#Pypi)
- [Usage](#usage)
- [Help](#help)
- [Disclaimer](#Disclaimer)


## Feature
- Uses multiple threads to speed up the search process.
- Displays HTTP code status and related information for each request.
- Support for custom word lists and configurable number of threads.


## Installation
Follow these steps to install 0xdirsan :

1. **Clone repositori**:
   ```sh
    git clone https://github.com/X-Projetion/0xdirsan.git
    cd 0xdirsan

2. **Clone repositori**:
   ```sh
   pip install -r requirements.txt
    ```


## Pypi Installation
- pip install 0xdirsan


## Usage
- python 0xdirsan.py -u <TARGET_URL>

## Help
```bash
usage: main.py [-h] [-w WORDLIST] -u URL [-t THREADS]

0xdirsan is a simple program designed to search for directories in a file system

optional arguments:
  -h, --help            show this help message and exit
  -w WORDLIST, --wordlist WORDLIST
                        Path to wordlist file
  -u URL, --url URL     Target URL use http / https
  -t THREADS, --threads THREADS
                        Number of threads (default 30)
```
### Connect with me:

- **Website:** [X-Projetion.org](https://x-projetion.org/)
- **Pypi:** [0xdirsan](https://pypi.org/project/0xdirsan/)
- **Instagram:** [@lutfifakee](https://www.instagram.com/lutfifakee/)
  
## Disclaimer
Please note that 0xdirsan is provided for educational purposes only. Use of this program for unethical or illegal activities is not recommended. The developer is not responsible for any actions taken by users.

<br>
<p>0xdirsan was developed by X-Projetion, a software developer with a focus on security and penetration testing. You can visit the website <a href="https://x-projetion.org/">X-Projetion.org</a> for more information or follow <a href="https://www.instagram. com/lutfifakee/">Instagram</a> X-Projetion for the latest updates.</p>


